==> kdesdk-3.2.3.tgz: include/cvsservice_stub.h <==
/****************************************************************************
**
** DCOP Stub Definition created by dcopidl2cpp from cvsservice.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#ifndef __CVSSERVICE_STUB__
#define __CVSSERVICE_STUB__

#include <dcopstub.h>
#include <qstringlist.h>
#include <dcopref.h>
#include <dcopobject.h>


class CvsService_stub : virtual public DCOPStub
{
public:
    CvsService_stub( const QCString& app, const QCString& id );
    CvsService_stub( DCOPClient* client, const QCString& app, const QCString& id );
    explicit CvsService_stub( const DCOPRef& ref );
    virtual DCOPRef add( const QStringList& files, bool isBinary );
    virtual DCOPRef addWatch( const QStringList& files, int events );
    virtual DCOPRef annotate( const QString& fileName, const QString& revision );
    virtual DCOPRef checkout( const QString& workingDir, const QString& repository, const QString& module, const QString& tag, bool pruneDirs );
    virtual DCOPRef commit( const QStringList& files, const QString& commitMessage, bool recursive );
    virtual DCOPRef createTag( const QStringList& files, const QString& tag, bool branch, bool force );
    virtual DCOPRef deleteTag( const QStringList& files, const QString& tag, bool branch, bool force );
    virtual DCOPRef downloadRevision( const QString& fileName, const QString& revision, const QString& outputFile );
    virtual DCOPRef downloadRevision( const QString& fileName, const QString& revA, const QString& outputFileA, const QString& revB, const QString& outputFileB );
    virtual DCOPRef diff( const QString& fileName, const QString& revA, const QString& revB, const QString& diffOptions, unsigned int contextLines );
    virtual DCOPRef edit( const QStringList& files );
    virtual DCOPRef editors( const QStringList& files );
    virtual DCOPRef history();
    virtual DCOPRef import( const QString& workingDir, const QString& repository, const QString& module, const QString& ignoreList, const QString& comment, const QString& vendorTag, const QString& releaseTag, bool importAsBinary );
    virtual DCOPRef lock( const QStringList& files );
    virtual DCOPRef log( const QString& fileName );
    virtual DCOPRef login( const QString& repository );
    virtual DCOPRef logout( const QString& repository );
    virtual DCOPRef makePatch();
    virtual DCOPRef moduleList( const QString& repository );
    virtual DCOPRef remove( const QStringList& files, bool recursive );
    virtual DCOPRef removeWatch( const QStringList& files, int events );
    virtual DCOPRef simulateUpdate( const QStringList& files, bool recursive, bool createDirs, bool pruneDirs );
    virtual DCOPRef status( const QStringList& files, bool recursive, bool tagInfo );
    virtual DCOPRef unedit( const QStringList& files );
    virtual DCOPRef unlock( const QStringList& files );
    virtual DCOPRef update( const QStringList& files, bool recursive, bool createDirs, bool pruneDirs, const QString& extraOpt );
    virtual DCOPRef watchers( const QStringList& files );
    virtual void quit();
protected:
    CvsService_stub() : DCOPStub( never_use ) {};
};


#endif

==> kdesdk-3.3.2.tgz: include/cvsservice_stub.h <==
/****************************************************************************
**
** DCOP Stub Definition created by dcopidl2cpp from cvsservice.kidl
**
** WARNING! All changes made in this file will be lost!
**
*****************************************************************************/

#ifndef __CVSSERVICE_STUB__
#define __CVSSERVICE_STUB__

#include <dcopstub.h>
#include <qstringlist.h>
#include <dcopref.h>
#include <dcopobject.h>


class CvsService_stub : virtual public DCOPStub
{
public:
    CvsService_stub( const QCString& app, const QCString& id );
    CvsService_stub( DCOPClient* client, const QCString& app, const QCString& id );
    explicit CvsService_stub( const DCOPRef& ref );
    virtual DCOPRef add( const QStringList& files, bool isBinary );
    virtual DCOPRef addWatch( const QStringList& files, int events );
    virtual DCOPRef annotate( const QString& fileName, const QString& revision );
    virtual DCOPRef checkout( const QString& workingDir, const QString& repository, const QString& module, const QString& tag, bool pruneDirs );
    virtual DCOPRef checkout( const QString& workingDir, const QString& repository, const QString& module, const QString& tag, bool pruneDirs, const QString& alias, bool exportOnly );
    virtual DCOPRef commit( const QStringList& files, const QString& commitMessage, bool recursive );
    virtual DCOPRef createRepository( const QString& repository );
    virtual DCOPRef createTag( const QStringList& files, const QString& tag, bool branch, bool force );
    virtual DCOPRef deleteTag( const QStringList& files, const QString& tag, bool branch, bool force );
    virtual DCOPRef downloadCvsIgnoreFile( const QString& repository, const QString& outputFile );
    virtual DCOPRef downloadRevision( const QString& fileName, const QString& revision, const QString& outputFile );
    virtual DCOPRef downloadRevision( const QString& fileName, const QString& revA, const QString& outputFileA, const QString& revB, const QString& outputFileB );
    virtual DCOPRef diff( const QString& fileName, const QString& revA, const QString& revB, const QString& diffOptions, unsigned int contextLines );
    virtual DCOPRef diff( const QString& fileName, const QString& revA, const QString& revB, const QString& diffOptions, const QString& format );
    virtual DCOPRef edit( const QStringList& files );
    virtual DCOPRef editors( const QStringList& files );
    virtual DCOPRef history();
    virtual DCOPRef import( const QString& workingDir, const QString& repository, const QString& module, const QString& ignoreList, const QString& comment, const QString& vendorTag, const QString& releaseTag, bool importAsBinary );
    virtual DCOPRef import( const QString& workingDir, const QString& repository, const QString& module, const QString& ignoreList, const QString& comment, const QString& vendorTag, const QString& releaseTag, bool importAsBinary, bool useModificationTime );
    virtual DCOPRef lock( const QStringList& files );
    virtual DCOPRef log( const QString& fileName );
    virtual DCOPRef login( const QString& repository );
    virtual DCOPRef logout( const QString& repository );
    virtual DCOPRef makePatch();
    virtual DCOPRef makePatch( const QString& diffOptions, const QString& format );
    virtual DCOPRef moduleList( const QString& repository );
    virtual DCOPRef remove( const QStringList& files, bool recursive );
    virtual DCOPRef removeWatch( const QStringList& files, int events );
    virtual DCOPRef simulateUpdate( const QStringList& files, bool recursive, bool createDirs, bool pruneDirs );
    virtual DCOPRef status( const QStringList& files, bool recursive, bool tagInfo );
    virtual DCOPRef unedit( const QStringList& files );
    virtual DCOPRef unlock( const QStringList& files );
    virtual DCOPRef update( const QStringList& files, bool recursive, bool createDirs, bool pruneDirs, const QString& extraOpt );
    virtual DCOPRef watchers( const QStringList& files );
    virtual void quit();
protected:
    CvsService_stub() : DCOPStub( never_use ) {};
};


#endif
